(*
**  ctl.inc
**
**  Structures for SETUP.FD
**
**  Copyright 1989-1993 Joaquim Homrighausen; All rights reserved.
**
**  Last revised: 93-06-23                         FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*)

(*
**  Mailer ------------------------------------------------------------------
*)

    { Loglevels }

CONST
  LOGFATAL              =$0001;                             {'!' Fatal errors}
  LOGERROR              =$0002;                                   {'?' Errors}
  LOGBRIEF              =$0004;                  {'+' Major changes in action}
  LOGACCT               =$0008;                   {'$' Accounting information}
  LOGXFER               =$0010;                      {'*' Sent/Received files}
  LOGTRIVIAL            =$0020;                  {'-' Minor changes in action}
  LOGXFERMSG            =$0040;                        {'%' Transfer messages}
  LOGMODEM              =$0080;               {'=' Modem activities/responses}
  LOGTRX                =$0100;              {':' Session transaction numbers}
  LOGSESSION            =$0200;               {'~' Session stuff, SysOp, etc.}
  LOGRMTAKAS            =$0400;                     {'~' Remote system's AKAs}
  LOGRMTINFO            =$0800;              {'~' Remote system's information}
  LOGUNEXPECT           =$1000;                      {'#' Unexpected password}
  LOGDEBUG              =$8000;                        {All loglevels enabled}

    { Miscellaneous flags (FLAGS) }

  NOUNLISTED            =$00000001;             {Don't allow unlisted systems}
  CREATE_BATCH          =$00000002;         {Create batchfile when BBS caller}
  TERMONLY              =$00000004;                 {Running as Terminal-Only}
  DTR_HANGUP            =$00000008;                        {Use DTR to hangup}
  DTR_DIAL              =$00000010;              {Toggle DTR prior to dialing}
  DTR_BUSY              =$00000020;                   {Use DTR to signal BUSY}
  MANUAL_ANSWER         =$00000040;                        {Use manual answer}
  CONNECT_RESET         =$00000080;             {Reset modem to connect speed}
  MODEM_FIXED           =$00000100;         {Use constant speed against modem}
  NOMAIL_NOPWD          =$00000200;           {No mail from unsecured systems}
  DELAYFIRST            =$00000400;                  {Delay before first call}
  CLOCK                 =$00000800;                            {Display clock}
  KILLNULL              =$00001000;             {Remove messages with no text}
  MAILONLY              =$00002000;                {Don't allow human callers}
  xxxxLIMITEDANSW       =$00004000;                  {Limited hours to answer}
  EXIT_NETMAIL          =$00008000;               {Exit when netmail received}
  ZONE_ADAPTION         =$00010000;                {Adopt called/calling zone}
  PRINTNEWMSGS          =$00020000;                  {Print received messages}
  NOUNKNOWNPOINTS       =$00040000;             {Don't accept unlisted points}
  FORCEDCARRIER         =$00080000;         {Carrier is forced. Ring required}
  NULLMODEM             =$00100000;            {Initiate session when CD high}
  MAILER43LINES         =$00200000;            {Use 43/50 line mode in mailer}
  SWAPTOEMSDISK         =$00400000;        {Swap file to LIM/EMS/DISK w/shell}
  MAILEREMSOK           =$00800000;          {If EMS can be used for swapping}
  PRESENTAKAS           =$01000000;        {Present AKAs during EMSI sessions}
  NOBLINKMAIL           =$02000000;        {Don't flash the waiting mail sign}
  EXITONANYFILE         =$04000000;        {Exit after ANY data has been rcvd}
  MAILERAUTOLINES       =$08000000;        {Use whatever screen mode is there}
  HONOR_RRQ             =$10000000;                                {Honor RRQ}
  NO_TIMESTAMP          =$20000000;         {Don't show timestamp in window-1}
  MAILERCUSTOMCRT       =$40000000;                 {User-defined screen size}

    { Miscellaneous flags (FLAGS2) }

  FAXAUTORECEIVE        =$00000001;                 {Handle inbound fax calls}
  MAILERLOGDFRS         =$00000002;           {Log data following RING signal}
  MEXTFREQS             =$00000004;              {Use external file ReqServer}
  MEXTFREQNOSWAP        =$00000008;        {Don't swap when calling ReqServer}
  FAXAUTOPRINT          =$00000010;         {Auto print faxes (internal only)}

    { Audio flags }

  CLOCKNOISE            =$0001;                      {Tic-tac-tic-tac-tic-tac}
  INMAILNOISE           =$0002;                            {Unpacked any mail}
  INCRASHNOISE          =$0004;             {Unpacked crash or immediate mail}
  INCONNECTNOISE        =$0008;                 {Incoming MAIL call (connect)}
  INCALLERNOISE         =$0010;            {Incoming human caller passed >BBS}
  MAILWAITING           =$0020;                              {Mail is waiting}
  OUTMAILNOISE          =$0040;                    {Sent mail (after session)}
  OUTCONNECTNOISE       =$0080;                 {Outgoing MAIL call (connect)}
  ERRORNOISE            =$0100;                                       {S.O.S.}

    { Request types }

  REQALL                =$01;                            {Anybody can request}
  REQNONE               =$02;                             {No one can request}
  REQLISTED             =$04;                            {Only listed systems}
  REQLIMITED            =$08;                                  {Limited hours}
  REQONLYONEMATCH       =$80;                 {Stop searching after one match}

TYPE
  _MAILER = RECORD
    Log         :ARRAY[1..71] of CHAR;                          {Log filename}
    LogLevel    :WORD;                                         {See Loglevels}

    Prefix      :ARRAY[1..31] of CHAR;                          {Always added}
    Hidden      :ARRAY[1..10] of ARRAY[1..31] of CHAR;
                                                {Strip these if they are in #}
    PostFix     :ARRAY[1..31] of CHAR;                       {Always appended}

    Flags,                                           {See Miscellaneous flags}
    Flags2      :LONGINT;                            {See Miscellaneous flags}

    Audio       :WORD;                                       {See Audio flags}
    SynchTimer  :BYTE;                  {Number of seconds before drop to BBS}

    crashexit   :BYTE;                                             {Mail exit}
    bbs300      :BYTE;                               {Human caller    300 BPS}
    bbs1200     :BYTE;                               {Human caller   1200 BPS}
    bbs1275     :BYTE;                               {Human caller  12/75 BPS}
    bbs2400     :BYTE;                               {Human caller   2400 BPS}
    bbs4800     :BYTE;                               {Human caller   4800 BPS}
    bbs9600     :BYTE;                               {Human caller   9600 BPS}
    bbs19200    :BYTE;                               {Human caller  19200 BPS}
    bbs38400    :BYTE;                               {Human caller  38400 BPS}

    modembaud   :WORD;                                 {30=300, 24=2400, etc.}
    modemport   :BYTE;                          {1-255 (COM1=1, COM2=2, etc.)}
    modemdelay  :BYTE;                        {1/10 seconds delay / line sent}

    b300msg     :ARRAY[1..16] of CHAR;                           {CONNECT 300}
    b1200msg    :ARRAY[1..16] of CHAR;                          {CONNECT 1200}
    b1275msg    :ARRAY[1..16] of CHAR;                          {CONNECT 1275}
    b2400msg    :ARRAY[1..16] of CHAR;                          {CONNECT 2400}
    b4800msg    :ARRAY[1..16] of CHAR;                          {CONNECT 4800}
    b9600msg    :ARRAY[1..16] of CHAR;                          {CONNECT 9600}
    b19200msg   :ARRAY[1..16] of CHAR;                         {CONNECT 19200}
    b38400msg   :ARRAY[1..16] of CHAR;                         {CONNECT 38400}
    errormsg    :ARRAY[1..16] of CHAR;                                 {ERROR}
    busymsg     :ARRAY[1..16] of CHAR;                                  {BUSY}
    carriermsg  :ARRAY[1..16] of CHAR;                            {NO CARRIER}
    okmsg       :ARRAY[1..16] of CHAR;                                    {OK}
    ringmsg     :ARRAY[1..16] of CHAR;                                  {RING}
    nodialmsg   :ARRAY[1..16] of CHAR;                           {NO DIALTONE}
    noanswmsg   :ARRAY[1..16] of CHAR;                             {NO ANSWER}
    voicemsg    :ARRAY[1..16] of CHAR;                                 {VOICE}

    escapestr   :ARRAY[1..11] of CHAR;                {Return to command mode}
    offhookstr  :ARRAY[1..11] of CHAR;                             {Busy line}
    reconnectstr:ARRAY[1..11] of CHAR;                   {Return to data mode}
    init1       :ARRAY[1..50] of CHAR;                      {Initialization-1}
    init2       :ARRAY[1..50] of CHAR;                      {Initialization-2}
    init3       :ARRAY[1..50] of CHAR;                      {Initialization-3}
    resetstr    :ARRAY[1..50] of CHAR;                   {Force "OK" response}
    downstr     :ARRAY[1..50] of CHAR;                    {Sent upon shutdown}
    hangupstr   :ARRAY[1..11] of CHAR;                               {On hook}
    dialstr     :ARRAY[1..11] of CHAR;                                  {Dial}

    oldmodemanswer:ARRAY[1..11] of CHAR;                         {!!Not used!!}
    answerdelay :BYTE;                          {1/10s delay before answering}

    begin_hour  :BYTE;                                          {!!Not used!!}
    begin_minute:BYTE;                                          {!!Not used!!}
    end_hour    :BYTE;                                          {!!Not used!!}
    end_minute  :BYTE;                                          {!!Not used!!}

    retrybusy   :BYTE;                              {Retry attempts when BUSY}
    retryresend :BYTE;                              {Retry attemps on failure}
    retrydelay  :BYTE;                                 {Seconds between calls}

    reqlist     :ARRAY[1..71] of CHAR;         {List to scan for reqable dirs}
    reqalias    :ARRAY[1..71] of CHAR;                       {Magic filenames}
    reqmessage  :ARRAY[1..71] of CHAR;    {Appended to FAILED REQUEST message}
    reqtype     :BYTE;                                             {See below}
    reqmaxfiles :BYTE;                  {Max number of files to send on 1 req}
    reqmaxtime  :WORD;                     {Maximum number of minutes for req}
    reqmaxsize  :WORD;                          {Maximum size (in KB) for req}
    OLDrminbaud :WORD;                                          {!!Not used!!}
    reqstarthr  :BYTE;                  {Start time for file requests, can be}
    reqstartmin :BYTE;                     {..combined with the reqdays field}
    reqendhr    :BYTE;                            {End time for file requests}
    reqendmin   :BYTE;
    reqdays     :BYTE;                 { 7 6 5 4 3 2 1           $80=All days
                                         _ _ _ _ _ _ _
                                         : : : : : : :
                                         : : : : : : +--- Saturday
                                         : : : : : +----- Friday
                                         : : : : +------- Thursday
                                         : : : +--------- Wednesday
                                         : : +----------- Tuesday
                                         : +------------- Monday
                                         +--------------- Sunday            }

    bbsname     :ARRAY[1..11] of CHAR;             {Press <Esc> for "bbsname"}
    beforebbsbanner:ARRAY[1..71] of CHAR;       {File sent before drop to BBS}

    KEY         :ARRAY[1..24] of                        {Mailer function keys}
      RECORD                                            {F1-F12, Shift F1-F12}
        Cmd        :ARRAY[1..61] of CHAR;                  {Program to execute}
        Title      :ARRAY[1..26] of CHAR;           {Title to appear on screen}
        Behavior   :BYTE;                {=$01-Pause, =$02-Rescan, =$04-NoSwap}
      END;{Record}

    Color       :ARRAY[1..11] of BYTE;                      {Header
                                                             Highlight
                                                             Clock
                                                             Data entry
                                                             Error
                                                             Normal text
                                                             Frame
                                                             Window text
                                                             Window frame
                                                             Window select
                                                             Window highlight}

    KeepHistory :BYTE;                  {Days to keep entries in mail history}

    slavepwd    :ARRAY[1..21] of CHAR;     {FDServer password, empty=inactive}

    ineventfile :ARRAY[1..71] of CHAR;      {Displayed to users when no users}
    mailonlyfile:ARRAY[1..71] of CHAR;     {Displayed to users when mail-only}

    ExternMail  :ARRAY[1..10] of                     {External mail interface}
      RECORD
        WakeUpStr  :ARRAY[1..39] of CHAR;              {String to trigger exit}
        Flags      :BYTE;                               {.$01=Leave FOSSIL hot}
        Errorlevel :BYTE;                             {Errorlevel to exit with}
      END;{Record}

    audio_begin_hour:BYTE;                    {Start and end of audio allowed}
    audio_begin_minute:BYTE;                    {If all four fields are zero,}
    audio_end_hour:BYTE;                     {..audio is allowed at all times}
    audio_end_minute:BYTE;

    min_undial_cost:WORD;                            {Minimum undialable cost}

    CDMASK      :BYTE;                               {Carrier detect mask (C)}

    FOSSIL_OUTBS,
    FOSSIL_INBS :WORD;                                          {!!Not used!!}

    reqseclist  :ARRAY[1..71] of CHAR;         {List to scan for reqable dirs}
                                               {...during SECURE sessions (C)}

    bbs7200     :BYTE;                               {Human caller   7200 BPS}
    bbs12000    :BYTE;                               {Human caller  12000 BPS}
    bbs14400    :BYTE;                               {Human caller  14400 BPS}

    SETcustomcrt_AX,                              {INT 10H register values to}
    SETcustomcrt_BX,                              {set CUSTOM screen mode (C)}
    SETcustomcrt_CX,
    SETcustomcrt_DX
                :WORD;

    RESETcustomcrt_AX,                            {INT 10H register values to}
    RESETcustomcrt_BX,                          {reset CUSTOM screen mode (C)}
    RESETcustomcrt_CX,
    RESETcustomcrt_DX
                :WORD;

    reqsecalias :ARRAY[1..71] of CHAR;            {Magic filenames for SECURE}
                                                                {sessions (C)}

    modemanswer :ARRAY[1..41] of CHAR;              {Instruct modem to answer}

    b7200msg    :ARRAY[1..16] of CHAR;                          {CONNECT 7200}
    b12000msg   :ARRAY[1..16] of CHAR;                         {CONNECT 12000}
    b14400msg   :ARRAY[1..16] of CHAR;                         {CONNECT 14400}
    b16800msg   :ARRAY[1..16] of CHAR;                         {CONNECT 16800}
    bfaxmsg     :ARRAY[1..16] of CHAR;                           {CONNECT FAX}

    bbs16800    :BYTE;                               {Human caller  16800 BPS}
    bbsfax      :BYTE;                                   {FAX call errorlevel}

    InboundFaxPath:ARRAY[1..71] of CHAR;                {Inbound fax path (C)}

    FReqServer  :ARRAY[1..71] of CHAR;          {External file request server}

    b57600msg   :ARRAY[1..16] of CHAR;                         {CONNECT 57600}
    b64000msg   :ARRAY[1..16] of CHAR;                         {CONNECT 64000}
    b115200msg  :ARRAY[1..16] of CHAR;                        {CONNECT 115200}

    bbs57600    :BYTE;                               {Human caller  57600 BPS}
    bbs64000    :BYTE;                               {Human caller  64000 BPS}
    bbs115200   :BYTE;                               {Human caller 115200 BPS}

    ModemCustomMsg:ARRAY[1..16] of CHAR;          {Custom CONNECT message (C)}
    ModemCustomBaud:LONGINT;                    {Actual baudrate of above (C)}
    bbsCustom   :BYTE;                           {Human caller Custom BPS (C)}

    reqminbaud  :LONGINT;                  {Minimum baudrate for file request}

    MailExitSemaphore:ARRAY[1..71] of CHAR;        {Touched/created when mail}
                                                       {has been received (C)}
    FaxPrinter  :ARRAY[1..71] of CHAR;            {Program to invoke to print}
                                                          {a received fax (C)}
    RESERVERAT  :ARRAY[1..369] of CHAR;                             {RESERVED}
  END;{_MAILER}

(*
**  Editor ------------------------------------------------------------------
*)

    { Miscellaneous flags (FLAGS) }

CONST
  EDITOR43LINES         =$00000001;                      {Use 43/50-line mode}
  SHOWHARDCRS           =$00000002;         {Display paragraph (hard CR) char}
  EDITORSWAP            =$00000004;          {Swap to LIM/EMS/DISK when shell}
  EDITOREMSOK           =$00000008;                    {EMS OK for swap image}
  EDITORAUTOLINES       =$00000010;        {Use whatever screen mode is there}
  HONOR_CFM             =$00000020;                                {Honor CFM}
  EDITORCUSTOMCRT       =$00000040;                 {User-defined screen size}
  RKILL_NEVER_E         =$00000080;           {Never ask "Delete Original?"-E}
  RKILL_NEVER_L         =$00000100;           {Never ask "Delete Original?"-L}
  RKILL_NEVER_N         =$00000200;           {Never ask "Delete Original?"-N}
  USEZONEGATE_YES       =$00000400;               {Always use zone gate if OK}
  USEZONEGATE_NO        =$00000800;          {Never use zone gate, even if OK}
  NEWMSGSEM             =$00001000;     {Semaphores when new msgs are created}
  FAXAUTOVIEW           =$00002000;         {View fax documents automatically}
  FAXAUTOKILL           =$00004000;   {Remove fax document with cover message}
                                 
    { Netmail folder behavior }

  RESTRICTED            =$00000001;                             {See FOLDER.H}
  EXPORTOK              =$00000004;
  USEXLATTABLES         =$00000008;
  EDREADONLY            =$00000020;

TYPE
  _EDITOR = RECORD
    MacroKey    :ARRAY[1..24] of ARRAY[1..61] of CHAR;  {F1-F12, Shift F1-F12}

    margin      :BYTE;                           {Wordwrap margin, default=60}

    msgbits     :WORD;                        {Default NetMail message status}

    flags       :LONGINT;                                          {See above}

    Origin      :ARRAY[1..20] of ARRAY[1..61] of CHAR;          {Origin lines}

    color       :ARRAY[1..15] of BYTE;                  {Top line
                                                         Status line
                                                         Error
                                                         Message text
                                                         Quoted message text
                                                         Reverse message text
                                                         Hard <CR>s
                                                         Message header
                                                         Message header data
                                                         Header data highlight
                                                         Input fields
                                                         Window frame
                                                         Window text
                                                         Window select
                                                         Window highlight}

    netfolderflags:LONGINT;                             {NetMail folder flags}

    translate_in:ARRAY[1..256] of CHAR;          {Translation table (reading)}
    translate_out:ARRAY[1..256] of CHAR;         {Translation table (writing)}

    qbase       :ARRAY[1..71] of CHAR;     {Path to Hudson Message Base (HMB)}

    SETcustomcrt_AX,                              {INT 10H register values to}
    SETcustomcrt_BX,                              {set CUSTOM screen mode (C)}
    SETcustomcrt_CX,
    SETcustomcrt_DX
                :WORD;

    RESETcustomcrt_AX,                            {INT 10H register values to}
    RESETcustomcrt_BX,                          {reset CUSTOM screen mode (C)}
    RESETcustomcrt_CX,
    RESETcustomcrt_DX
                :WORD;

    FaxViewer   :ARRAY[1..71] of CHAR;      {Program invoked by <Ctrl-F3> (C)}

    RESERVERAT  :ARRAY[1..937] of CHAR;                             {RESERVED}
  END;{_EDITOR}

(*
**  Shared data -------------------------------------------------------------
*)

    { Miscellaneous flags (FLAGS) }

CONST
  FASTKEY               =$00000001;                 {Set/reset typematic rate}
  FLICKER               =$00000002;          {Prevent flicker on CGA monitors}
  BLACKOUT              =$00000004;                    {Screen blanker active}
  HAVEEXTKBD            =$00000008;      {Use extended INT 16H keyboard calls}
  FORCE24HOUR           =$00000010;                {Force 24-hour time format}
  MONOMODE              =$00000020;              {Monochrome mode for FDSETUP}

    { User flags }

  SUPERUSER             =$00000001;
  ADMINUSER             =$00000002;
  USER                  =$00000004;
  BYPASSRO              =$00010000;             {Bypass Read-only restriction}
  BYPASSEXP             =$00020000;                {Bypass Export restriction}

    { Protection flags }

  PROTECT_MEXIT         =$00000001;                 {Mailer Protect Alt-Q (C)}
  PROTECT_MSHELL        =$00000002;                 {Mailer Protect Alt-Z (C)}
  PROTECT_MKEYS         =$00000004;         {Mailer Protect function keys (C)}
  PROTECT_MFREQ         =$00000008;         {Mailer Protect file requests (C)}
  PROTECT_MXMIT         =$00000010;              {Mailer Protect transmit (C)}
  PROTECT_MSEND         =$00000020;             {Mailer Protect send mail (C)}
  PROTECT_MPOLL         =$00000040;                  {Mailer Protect poll (C)}
  PROTECT_MNCOMP        =$00000080;                  {Mailer Protect FDNC (C)}
  PROTECT_MQUEUE        =$00000100;            {Mailer Protect mail queue (C)}
  PROTECT_MPRN          =$00000200;        {Mailer Protect printer toggle (C)}

    { FTN-Domain structure }

TYPE
  _DOMAIN = RECORD
    Zone,
    Reserved    :WORD;                                       {Zone for domain}
    Name        :ARRAY[1..28] of CHAR;                        {Name of domain}
  END;{_DOMAIN}

    { AKA matching structure }

  _ZMATCH = RECORD
    Zone,                                                      {Zone to match}
    Net         :WORD;                                          {Net to match}
    AkaNum      :WORD;                             {AKA to use, 0=Primary AKA}
  END;{_ZMATCH}

  _SHARED = RECORD
    systempath  :ARRAY[1..71] of CHAR;                           {SYSTEM path}
    mailpath    :ARRAY[1..71] of CHAR;                 {System NetMail folder}
    swap_path   :ARRAY[1..71] of CHAR;                   {Path for swap files}
    rescanpath  :ARRAY[1..71] of CHAR;                   {Semaphore files (C)}
    infilesecpath:ARRAY[1..71] of CHAR;      {Rcvd files, SECURE sessions (C)}
    infilepath  :ARRAY[1..71] of CHAR;                            {Rcvd files}
    packetpath  :ARRAY[1..71] of CHAR;          {Path for outbound .PKT files}
    nodelistpath:ARRAY[1..71] of CHAR;            {Path for nodelist database}

    countrycode :WORD;                  {Country code for tel.no. translation}

    AKA : ARRAY[1..11] of                   {One primary address and ten AKAs}
      RECORD
        Zone,
        Net,
        Node,
        Point   :WORD;
      END;{Record}

    flags       :LONGINT;                                          {See above}

    blackout_time:BYTE;                      {Screen blanker timer in seconds}

    { User record }

    Users : ARRAY[1..10] of                                            {Users}
      RECORD
        Name    :ARRAY[1..37] of CHAR;                              {Username}
        PwdCRC  :LONGINT;                {CRC-32 of user password, -1L No pwd}
        Flags   :LONGINT;                              {User flags, see above}
      END;{Record}

    exitpwdcrc  :LONGINT;            {Password for DOS shell, exits, etc. (C)}
    exitflags   :LONGINT;                {Which flags should be protected (C)}

    Zmatch      :ARRAY[1..20] of _ZMATCH;                 {AKA matching table}
    Domain      :ARRAY[1..20] of _DOMAIN;                   {FTN domain table}

    SiteInfo : RECORD                                       {Site information}
      Name      :ARRAY[1..50] of CHAR;                        {Name of system}
      Location  :ARRAY[1..40] of CHAR;                    {Location of system}
      PhoneNo   :ARRAY[1..26] of CHAR;       {Phone number or '-Unpublished-'}
      Baudrate  :LONGINT;                             {Baud rate (300-115200)}
      Flags     :ARRAY[1..50] of CHAR;            {Capability flags of system}
    END;{SiteInfo}

    FaxRecipient:WORD;                           {Fax recipient (0-based) (C)}

    RESERVED    :ARRAY[1..84] of CHAR;                              {RESERVED}
  END;{_SHARED}

(*
**  Terminal ----------------------------------------------------------------
*)

    { Miscellaneous flags (FLAGS) }

CONST
  CONNECT_NOISE         =$00000001;                    {Make noise on connect}
  TRANSFER_NOISE        =$00000002;                {Make noise after transfer}
  USE_TRANSLATE         =$00000004;                   {Use translation tables}
  USE_43LINES           =$00000008;                      {Use 43/50-line mode}
  AUTOZMODEM            =$00000010;              {Allow auto-Zmodem downloads}
  NOWRAPAROUND          =$00000020;               {Disable automatic wrapping}
  LOCALECHO             =$00000040;                  {Echo local input to CRT}
  NOAVATAR              =$00000080;                {Disable AVATAR/0+ support}
  USE_AUTOLINES         =$00000100;       {Use whatever screen mode is active}
  NOCLRONFF             =$00000200;         {Don't clear screen on form feeds}
  IEMSIACTIVE           =$00000400;                 {Interactive EMSI Support}
  TERMCUSTOMCRT         =$00000800;             {User-defined screen size (C)}
  TERMLOG               =$00001000;                  {Logging in Terminal (C)}

TYPE
  _TERMINAL = RECORD
    InitString  :ARRAY[1..41] of CHAR;                  {Modem initialization}

    ScrollSize  :WORD;                 {Maximum memory (kb) for scroll buffer}

    emulation   :BYTE;                        {0=TTY, 1=ANSI, 2=VT52, 3=VT100}

    protocol    :BYTE;                       {Default file transfer protocol}

    ShiftKey    :ARRAY[1..12] of ARRAY[1..31] of CHAR;          {Shift F1-F12}
    CtrlKey     :ARRAY[1..12] of ARRAY[1..31] of CHAR;           {Ctrl F1-F12}

    downloadpath:ARRAY[1..60] of CHAR;                 {Default download path}
    uploadpath  :ARRAY[1..60] of CHAR;                   {Default upload path}

    translate_in:ARRAY[1..256] of CHAR;            {Inbound translation table}
    translate_out:ARRAY[1..256] of CHAR;          {Outbound translation table}

    retrywait   :BYTE;                      {Seconds to wait before next dial}

    flags       :LONGINT;                                           {See above}

    directorypwd:LONGINT;              {CRC-32 of password to enter phone dir}

    editor      :ARRAY[1..60] of CHAR;          {Program to invoke on <Alt-I>}

    profile     :ARRAY[1..94] of CHAR;       {Default profile, see TERMINAL.H}

    SETcustomcrt_AX,                              {INT 10H register values to}
    SETcustomcrt_BX,                              {set CUSTOM screen mode (C)}
    SETcustomcrt_CX,
    SETcustomcrt_DX
                :WORD;

    RESETcustomcrt_AX,                            {INT 10H register values to}
    RESETcustomcrt_BX,                          {reset CUSTOM screen mode (C)}
    RESETcustomcrt_CX,
    RESETcustomcrt_DX
                :WORD;

    RESERVERAT  :ARRAY[1..854] of CHAR;                             {RESERVED}
  END;{_TERMINAL}

(*
**  Printer (C) -------------------------------------------------------------
*)

    { Miscellaneous flags (BEHAVIOR) }

CONST
  PAGE_FORMAT           =$00000001;
  PAGE_FFEED            =$00000002;
  EJECT                 =$00000004;
  MANUAL_PAPER          =$00000008;
  HIDE_KLUDGE           =$00000010;
  CONTINOUS             =$00000020;

TYPE
  _PRINTER = RECORD
    Port        :BYTE;                {0=LPT1, 1=LPT2, 2=LPT3, 3=COM1, 4=COM2}
    Baudrate    :BYTE;                        {0=9600, 1=4800, 2=2400, 3=1200}
    stopbits    :BYTE;                                              {0=1, 1=2}
    wordlength  :BYTE;                                              {0=7, 1=8}
    parity      :BYTE;                                 {0=Even, 1=Odd, 2=None}
    pagelen     :BYTE;                           {Number of lines on one page}
    behavior    :LONGINT;                                          {See above}
    init        :ARRAY[1..71] of CHAR;                           {Initialization}
    reset       :ARRAY[1..71] of CHAR;                        {Deinitialization}
    bold_on     :ARRAY[1..31] of CHAR;
    bold_off    :ARRAY[1..31] of CHAR;
    under_on    :ARRAY[1..31] of CHAR;
    under_off   :ARRAY[1..31] of CHAR;
    italic_on   :ARRAY[1..31] of CHAR;
    italic_off  :ARRAY[1..31] of CHAR;
    pagewidth   :BYTE;                            {Width in columns of a page}
    leftmargin  :BYTE;                                           {Left margin}
    footer      :BYTE;                     {Footer margin, ie. leave nn lines}
    header      :BYTE;                      {Header margin, ie. skip nn lines}
    translate_out:ARRAY[1..256] of CHAR;                   {Translation table}
    Reserved    :ARRAY[1..100] of CHAR;                             {RESERVED}
  END;{_PRINTER}

(*
**  SETUP.FD ----------------------------------------------------------------
**
** Don't use ANY of the data in the file if the CRC values are NOT correct.
**
** Check the fingerprint[] field before assuming 1.99b and higher. Your
** software should also check the sysrev field to make sure it's compatible
** with the data listed in SETUP.FD
*)

    { Current system file revision level }

CONST
  FD_THISREV            =$0100;

TYPE
  _CTL = RECORD
    FingerPrint :ARRAY[1..5] of CHAR;               {Must contain "JoHo<NUL>"}
    sysrev      :WORD;                            {Must contain THISREV above}
    ctlcrc      :LONGINT;              {CRC-32 of _ctl excluding 1st 11 bytes}
    m           :_MAILER;
    e           :_EDITOR;
    s           :_SHARED;
    t           :_TERMINAL;
    p           :_PRINTER;
    ctlcrc2     :LONGINT;                            {CRC-32 of all the above}
  END;{_CTL}

(* end of file "ctl.inc" *)
