/*
**  event.h
**
**  Structures for EVENT.FD
**
**  Copyright 1991-1993 Joaquim Homrighausen; All rights reserved.
**
**  Last revised: 93-06-21                         FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __EVENT_H__
#define __EVENT_H__

#ifdef __cplusplus
extern "C" {
#endif

    /* Day values */

#define MONDAY          0x01
#define TUESDAY         0x02
#define WEDNESDAY       0x04
#define THURSDAY        0x08
#define FRIDAY          0x10
#define SATURDAY        0x20
#define SUNDAY          0x40
#define ALL             0x80

    /* Miscellaneous flags (BEHAVE) */

#ifndef _NOTEVENT_

#define USERS_OK        0x00000001L         /*Allow users to interrupt event*/
#define MAIL_EXIT       0x00000002L             /*Exit when mail is received*/
#define CRASH_ONLY      0x00000004L                   /*Only send Crash mail*/
#define FREQ_OK         0x00000008L            /*Honor inbound file requests*/
#define DO_PICKUP       0x00000010L      /*Pickup mail during outbound calls*/
#define ALLOW_PICKUP    0x00000020L     /*Allow calling nodes to pickup mail*/
#define SEND_ONLY       0x00000040L    /*Send only, don't wait between calls*/
#define RECV_ONLY       0x00000080L     /*Receive only, don't make any calls*/
#define FORCED          0x00000100L   /*Event is forced and MUST be executed*/
#define ENDNOMAIL       0x00000200L   /*End event when no more outgoing mail*/
#define SENDTOCM        0x00000400L                /*Send to CM systems only*/
#define SENDTONOCM      0x00000800L            /*Send to non-CM systems only*/
#define ONLYONCE        0x00001000L     /*Only call a node once during event*/
#define PICKUPFREQ      0x00002000L  /*Honor file requests on outbound calls*/
#define HOLDFREQ        0x00004000L  /*Don't send file requests during event*/
#define HOLDFATT        0x00008000L  /*Don't send file attaches during event*/
#define DONTANSWER      0x00010000L        /*Don't answer phone during event*/
/* .. gap .. */
#define DELETED         0x40000000L                  /*Never written to disk*/
#define INACTIVE        0x80000000L           /*Inactive (ignored by Mailer)*/

/*
**  The first record in EVENT.FD must be the EVENTBASE and have the tag
**  field set to "@".
*/
typedef struct
    {
    char                tag;                    /*Event tag A-Z (X=External)*/
    unsigned char       day;            /*Days to execute event on, bit mask*/
    char                mud, /*'-'=Subtract '+'= Add '*'=Don't use eventbase*/
                        s_hr,                /*Starting hour, 24 hour format*/
                        s_mi,                              /*Starting minute*/
                        l_hr,               /*Length (hours), 24 hour format*/
                        l_mi;                              /*Length (minute)*/
    unsigned char       level;      /*Errorlevel for X-events and mail exits*/
    unsigned long       behave;        /*Event behavior, non-exclusive value*/
    short int           cost;/*Maxmium cost of mail to go out, -1 don't care*/
    short int           lastrun;        /*Packed DOS date when last executed*/
    char                RESERVED0;                                /*RESERVED*/
    unsigned short int  timer;   /*Delay between calls in seconds, 0=Default*/
    unsigned short int  mincost;       /*Minimum cost for messages to go out*/
    char                RESERVED1;                                /*RESERVED*/
    }
    EVENT, *EVENTPTR;

#endif

#ifdef __cplusplus
}
#endif
#endif

/* end of file "event.h" */
