(*
**  event.inc
**
**  Structures for EVENT.FD
**
**  Copyright 1991-1993 Joaquim Homrighausen; All rights reserved.
**
**  Last revised: 93-06-21                         FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*)

    { Day values }

CONST
  MONDAY          =$01;
  TUESDAY         =$02;
  WEDNESDAY       =$04;
  THURSDAY        =$08;
  FRIDAY          =$10;
  SATURDAY        =$20;
  SUNDAY          =$40;
  ALL             =$80;

    { Miscellaneous flags (BEHAVE) }

{$IFNDEF _NOTEVENT_}

  USERS_OK        =$00000001;                 {Allow users to interrupt event}
  MAIL_EXIT       =$00000002;                     {Exit when mail is received}
  CRASH_ONLY      =$00000004;                           {Only send Crash mail}
  FREQ_OK         =$00000008;                    {Honor inbound file requests}
  DO_PICKUP       =$00000010;              {Pickup mail during outbound calls}
  ALLOW_PICKUP    =$00000020;             {Allow calling nodes to pickup mail}
  SEND_ONLY       =$00000040;            {Send only, don't wait between calls}
  RECV_ONLY       =$00000080;             {Receive only, don't make any calls}
  FORCED          =$00000100;           {Event is forced and MUST be executed}
  ENDNOMAIL       =$00000200;           {End event when no more outgoing mail}
  SENDTOCM        =$00000400;                        {Send to CM systems only}
  SENDTONOCM      =$00000800;                    {Send to non-CM systems only}
  ONLYONCE        =$00001000;             {Only call a node once during event}
  PICKUPFREQ      =$00002000;          {Honor file requests on outbound calls}
  HOLDFREQ        =$00004000;          {Don't send file requests during event}
  HOLDFATT        =$00008000;          {Don't send file attaches during event}
  DONTANSWER      =$00010000;                {Don't answer phone during event}
  { .. gap .. }
  DELETED         =$40000000;                          {Never written to disk}
  INACTIVE        =$80000000;                   {Inactive (ignored by Mailer)}

(*
**  The first record in EVENT.FD must be the EVENTBASE and have the tag
**  field set to "@".
*)
TYPE
  EVENT = RECORD
    Tag     :CHAR;                                {Event tag A-Z (X=External)}
    Day     :BYTE;                        {Days to execute event on, bit mask}
    mud     :CHAR;             {'-'=Subtract '+'= Add '*'=Don't use eventbase}
    s_hr    :BYTE;                             {Starting hour, 24 hour format}
    s_mi    :BYTE;                                           {Starting minute}
    l_hr    :BYTE;                            {Length (hours), 24 hour format}
    l_mi    :BYTE;                                           {Length (minute)}
    Errorlevel:BYTE;                  {Errorlevel for X-events and mail exits}
    Behave  :LONGINT;                    {Event behavior, non-exclusive value}
    cost    :WORD;             {Maxmium cost of mail to go out, -1 don't care}
    lastrun :WORD;                        {Packed DOS date when last executed}
    RSRVD0  :BYTE;                                                  {RESERVED}
    timer   :WORD;                 {Delay between calls in seconds, 0=Default}
    mincost :WORD;                       {Minimum cost for messages to go out}
    RSRVD1  :BYTE;                                                  {RESERVED}
  END;{EVENT}

{$ENDIF}

(* end of file "event.inc" *)
