/*
**  lastcall.h
**
**  Structures for LASTCALL.FD
**
**  Copyright 1991-1993 Joaquim Homrighausen; All rights reserved.
**
**  Last revised: 93-06-21                         FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __LASTCALL_H__
#define __LASTCALL_H__

#ifdef __cplusplus
extern "C" {
#endif

typedef struct
    {
    unsigned short int  inbound,                        /*Inbound mail calls*/
                        outbound,                      /*Outbound mail calls*/
                        humans,                        /*Inbound BBS callers*/
                        filesin,                            /*Received files*/
                        filesout,                               /*Sent files*/
                        goodsess,                            /*Good sessions*/
                        badsess,                           /*Failed sessions*/
                        requests;                    /*Inbound file requests*/
    unsigned long       date,                         /*UNIX-style timestamp*/
                        bytesin,                            /*Received bytes*/
                        bytesout;                               /*Sent bytes*/
    }
    STATREC, *STATRECPTR;

/*
**  Note that the two char[] fields are in Pascal fashion. The first byte is
**  the length byte. The actual string starts at [1] and the string is NOT
**  NUL terminated.
*/
typedef struct
    {
    char                system_name[31],              /*Remote system's name*/
                        location[41];             /*Remote system's location*/
    unsigned short int  zone,                      /*Remote system's address*/
                        net,
                        node,
                        point;
    unsigned long       time;                         /*UNIX-style timestamp*/
    }
    LASTCALL, *LASTCALLPTR;

/*
**  The LASTCALL.FD file contains four records, two STATREC and two
**  LASTCALL. Today's activity is moved to yesterday's activity as soon
**  as FD runs its 'past-midnight' internal event.
*/
typedef struct
    {
    LASTCALL            lastin,                     /*Last inbound mail call*/
                        lastout;                   /*Last outbound mail call*/
    STATREC             today_act,                        /*Today's activity*/
                        yesterday_act;                /*Yesterday's activity*/
    }
    ACTIVITY, *ACTIVITYPTR;

#ifdef __cplusplus
}
#endif
#endif

/* end of file "lastcall.h" */
