/*
**  linecfg.h
**
**  Structure for MDCFG<TaskNum>.FD
**
**  Copyright 1993 Joaquim Homrighausen; All rights reserved.
**
**  Last revised: 93-06-20                    FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __LINECFG_H__
#define __LINECFG_H__

#ifdef __cplusplus
extern "C" {
#endif

#define LINECFG_REV             0x0100

/*
**    Modem flags
*/
#define MODEMCFG_DTR_HANGUP     0x00000001L              /*Use DTR to hangup*/
#define MODEMCFG_DTR_DIAL       0x00000002L    /*Toggle DTR prior to dialing*/
#define MODEMCFG_DTR_BUSY       0x00000004L         /*Use DTR to signal BUSY*/
#define MODEMCFG_MANUAL_ANSWER  0x00000008L              /*Use manual answer*/
#define MODEMCFG_CONNECT_RESET  0x00000010L   /*Reset modem to connect speed*/
#define MODEMCFG_FIXED          0x00000020L             /*Constant DTE speed*/
#define MODEMCFG_NULLMODEM      0x00000040L  /*Initiate session when CD high*/
#define MODEMCFG_FAXAUTORECEIVE 0x00000080L       /*Handle inbound fax calls*/
#define MODEMCFG_MAILERLOGDFRS  0x00000100L /*Log data following RING signal*/

typedef struct
    {
    unsigned long       Flags;                        /*Modem specific flags*/
    unsigned short int  Baudrate;                    /*30=300, 24=2400, etc.*/
    unsigned char       COMport;              /*1-255 (COM1=1, COM2=2, etc.)*/
    unsigned char       LineDelay;          /*1/10 seconds delay / line sent*/
    unsigned char       CDMASK;

    /* Connect messages */

    char    b300Msg[16];
    char    b1200Msg[16];
    char    b1275Msg[16];
    char    b2400Msg[16];
    char    b4800Msg[16];
    char    b7200Msg[16];
    char    b9600Msg[16];
    char    b12000Msg[16];
    char    b14400Msg[16];
    char    b16800Msg[16];
    char    b19200Msg[16];
    char    b38400Msg[16];
    char    b57600Msg[16];
    char    b64000Msg[16];
    char    b115200Msg[16];
    char    ModemCustomMsg[16];
    long    ModemCustomBaud;
    char    bfaxMsg[16];
    char    errorMsg[16];
    char    busyMsg[16];
    char    carrierMsg[16];
    char    okMsg[16];
    char    ringMsg[16];
    char    nodialMsg[16];
    char    noanswMsg[16];
    char    voiceMsg[16];

    /* Command strings */

    char    modemanswer[41];
    unsigned char
            AnswerDelay;

    char    escapestr[11];
    char    offhookstr[11];
    char    reconnectstr[11];
    char    init1[50];
    char    init2[50];
    char    init3[50];
    char    resetstr[50];
    char    downstr[50];
    char    hangupstr[11];
    char    dialstr[11];
    char    prefix[31];                                       /*Always added*/
    char    postfix[31];                                   /*Always appended*/
    }
    MODEMCFG;

typedef struct
    {
    char    Fingerprint[5];                       /*Must contain "JoHo<NUL>"*/
    unsigned short int
            FileRevision;                                      /*LINECFG_REV*/
    unsigned long
            CRC1;                  /*CRC32 of LINECFG excluding 1st 11 bytes*/
    MODEMCFG
            Modem;
    unsigned long
            CRC2;                                  /*CRC-32 of all the above*/
    }
    LINECFG;

#ifdef __cplusplus
}
#endif
#endif

/* end of file "linecfg.h"*/
