(*
**  linecfg.inc
**
**  Structure for MDCFG<TaskNum>.FD
**
**  Copyright 1993 Joaquim Homrighausen; All rights reserved.
**
**  Last revised: 93-06-20                    FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*)

CONST
  LINECFG_REV           =$0100;

  { Modem flags }

  MODEMCFG_DTR_HANGUP   =$00000001;                        {Use DTR to hangup}
  MODEMCFG_DTR_DIAL     =$00000002;              {Toggle DTR prior to dialing}
  MODEMCFG_DTR_BUSY     =$00000004;                   {Use DTR to signal BUSY}
  MODEMCFG_MANUAL_ANSWER=$00000008;                        {Use manual answer}
  MODEMCFG_CONNECT_RESET=$00000010;             {Reset modem to connect speed}
  MODEMCFG_FIXED        =$00000020;                       {Constant DTE speed}
  MODEMCFG_NULLMODEM    =$00000040;            {Initiate session when CD high}
  MODEMCFG_FAXAUTORECEIVE=$00000080;                {Handle inbound fax calls}
  MODEMCFG_MAILERLOGDFRS=$00000100;           {Log data following RING signal}

TYPE
  MODEMCFG = RECORD
    Flags     :LONGINT;                                 {Modem specific flags}
    Baudrate  :WORD;                                   {30=300, 24=2400, etc.}
    COMport   :BYTE;                            {1-255 (COM1=1, COM2=2, etc.)}
    LineDelay :BYTE;                          {1/10 seconds delay / line sent}
    CDMASK    :BYTE;

    { Connect messages }

    b300Msg   :ARRAY[1..16] of CHAR;
    b1200Msg  :ARRAY[1..16] of CHAR;
    b1275Msg  :ARRAY[1..16] of CHAR;
    b2400Msg  :ARRAY[1..16] of CHAR;
    b4800Msg  :ARRAY[1..16] of CHAR;
    b7200Msg  :ARRAY[1..16] of CHAR;
    b9600Msg  :ARRAY[1..16] of CHAR;
    b12000Msg :ARRAY[1..16] of CHAR;
    b14400Msg :ARRAY[1..16] of CHAR;
    b16800Msg :ARRAY[1..16] of CHAR;
    b19200Msg :ARRAY[1..16] of CHAR;
    b38400Msg :ARRAY[1..16] of CHAR;
    b57600Msg :ARRAY[1..16] of CHAR;
    b64000Msg :ARRAY[1..16] of CHAR;
    b115200Msg:ARRAY[1..16] of CHAR;
    ModemCustomMsg:ARRAY[1..16] of CHAR;
    ModemCustomBaud:LONGINT;
    bfaxMsg   :ARRAY[1..16] of CHAR;
    errorMsg  :ARRAY[1..16] of CHAR;
    busyMsg   :ARRAY[1..16] of CHAR;
    carrierMsg:ARRAY[1..16] of CHAR;
    okMsg     :ARRAY[1..16] of CHAR;
    ringMsg   :ARRAY[1..16] of CHAR;
    nodialMsg :ARRAY[1..16] of CHAR;
    noanswMsg :ARRAY[1..16] of CHAR;
    voiceMsg  :ARRAY[1..16] of CHAR;

    { Command strings }

    modemanswer:ARRAY[1..41] of CHAR;
    AnswerDelay:BYTE;

    escapestr :ARRAY[1..11] of CHAR;
    offhookstr:ARRAY[1..11] of CHAR;
    reconnectstr:ARRAY[1..11] of CHAR;
    init1     :ARRAY[1..50] of CHAR;
    init2     :ARRAY[1..50] of CHAR;
    init3     :ARRAY[1..50] of CHAR;
    resetstr  :ARRAY[1..50] of CHAR;
    downstr   :ARRAY[1..50] of CHAR;
    hangupstr :ARRAY[1..11] of CHAR;
    dialstr   :ARRAY[1..11] of CHAR;
    prefix    :ARRAY[1..31] of CHAR;                            {Always added}
    postfix   :ARRAY[1..31] of CHAR;                         {Always appended}
  END;{MODEMCFG}

  LINECFG = RECORD
    FingerPrint:ARRAY[1..5] of CHAR;                {Must contain "JoHo<NUL>"}
    FileRevision:WORD;                                           {LINECFG_REV}
    CRC1      :LONGINT;              {CRC32 of LINECFG excluding 1st 11 bytes}
    Modem     :MODEMCFG;
    CRC2      :LONGINT;                              {CRC-32 of all the above}
  END;{LINECFG}

(* end of file "linecfg.inc" *)
