/*
**  sreq.h
**
**  Structures of file created during an inbound service request and when
**  the FrontDoor Mailer invokes an external file request processor. This
**  filename is obtained with the =F macro.
**
**  NOTE: The format of this file is INCOMPATIBLE with the format used by
**        versions prior to 2.11.
**
**  Copyright 1991-1993 Joaquim Homrighausen; All rights reserved.
**
**  Last revised: 93-06-20                         FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/
#ifndef __SREQ_H__
#define __SREQ_H__

#ifdef __cplusplus
extern "C" {
#endif

/*
**  The structure of the file is as follows:
**
**      <_InfoRec>
**      <NumValidEntriesInIDList>    (16-bit integer)
**      <_RemoteID * above>
**
**  All char[] fields are Pascal style (i.e. the first byte is the length
**  byte and there is no terminating NUL character).
*/
typedef struct
    {
    unsigned short int  Zone,                                      /*Address*/
                        Net,
                        Node,
                        Point;
    unsigned char       Denied;          /*Whether "DENY" applies to address*/
    }
    _RemoteID;

typedef struct
    {
    char                SystemName[81],                        /*System name*/
                        SystemOperator[81],                /*System operator*/
                        SystemLocation[41],                /*System location*/
                        SystemPhone[27],     /*System telephone number (raw)*/
                        SystemDomain[30];
    unsigned long       Baudrate;              /*Maximum baud rate of system*/
    char                Flags[52];           /*Nodelist flags (as presented)*/
    unsigned short int  Zone,  /*Primary AKA, same as first _RemoteID record*/
                        Net,
                        Node,
                        Point;
    unsigned long       Capabilities;/*Nodelist flags (as found in Nodelist)*/
    char                TrxNum[11];                     /*Transaction number*/
                        SerialNumber[32],                    /*Serial number*/
                        Password[18];               /*Session level password*/
    }
    _InfoRec;

#ifdef __cplusplus
}
#endif
#endif

/* end of file "sreq.h" */
