(*
**	terminal.inc
**
**	Structures for TERMPHON.FD, TERMPROF.FD, and TERMKEYS.FD
**
**	Copyright 1991-1993 Joaquim Homrighausen; All rights reserved.
**
**	Last revised: 93-06-18                         FrontDoor 2.11+
**
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*)

(*
**	TERMPHON.FD - Internal terminal telephone directory record
*)
TYPE
	PHONEREC = RECORD
		Name		:STRING[30];                                         {System name}
		Number	:STRING[34];                          {Telephone number as dialed}
		Password:STRING[16];                        {Default password for session}
		Baud		:WORD;                                                 {Baud rate}
		Flags		:LONGINT;                         {See below under 'Entry Flags:'}
		Protocol:BYTE;                          {Preferred file transfer protocol}
		Parity	:BYTE;                                                    {Parity}
		WordLen	:BYTE;                                    {# of data bits, 7 or 8}
		StopBits:BYTE;                                    {# of stop bits, 1 or 2}
		Emulation:BYTE;                                       {Terminal emulation}
		KeySet	:WORD;                      {Key definition record, $FFFF=DEFAULT}
		Profile	:WORD;                                 {Profile record, 0=DEFAULT}
    Script	:STRING[8];                    {Script name to use, blank if none}
	END;{PHONEREC}

	{ Phone record flags }

CONST
	TPHONE_XLATON					=$00000001;                   {Use translation tables}
	TPHONE_INQUEUE				=$00000002;                       {Queued for dialing}
	TPHONE_LFEXPAND				=$00000004;                  {On=CR->CR/LF Off=CR->CR}
	TPHONE_NOWRAP   			=$00000008;            {Don't wrap lines when xpos=80}
	TPHONE_LECHO    			=$00000010;         {Echo keyboard input to local CRT}
	TPHONE_NOAVATAR 			=$00000020;                      {No AVATAR sequences}
	TPHONE_NOIEMSI  			=$00000040;                                 {No IEMSI}
	TPHONE_DELETED  			=$80000000;           {Entry is deleted, never stored}

(*
**	TERMPROF.FD - Profile record
**
**	All strings are NUL terminated, a'la C ASCIIZ strings.
*)
TYPE
	PROFILE = RECORD
		Username:ARRAY[1..30] of CHAR;                                 {User name}
		Handle	:ARRAY[1..20] of CHAR;                                    {Handle}
		Password:ARRAY[1..20] of CHAR;                                  {Password}
		Flags		:LONGINT;                       {See below under 'Profile Flags:'}
		RESERVED:ARRAY[1..20] of CHAR;                                  {Reserved}
	END;{PROFILE}

	{ Profile flags: }

CONST
	PRF_HOTKEYS     			=$00000001;                                  {Hotkeys}
	PRF_QUIET       			=$00000002;                            {Don't disturb}
	PRF_MORE        			=$00000004;                             {Page pausing}
	PRF_EDITOR      			=$00000008;                   {Use full-screen editor}
	PRF_NEWS        			=$00000010;               {Show bulletins, news, etc.}
	PRF_NEWMAIL     			=$00000020;                       {Check for new mail}
	PRF_NEWFILE     			=$00000040;                      {Check for new files}
	PRF_CLRSCR      			=$00000080;                          {Screen clearing}

(*
**	TERMKEYS.FD - Keyset record
*)
TYPE
	KEYREC = RECORD
		ShiftKeys	:ARRAY[1..12] of STRING[30];                      {Shift F1-F12}
		CtrlKeys	:ARRAY[1..12] of STRING[30];                       {Ctrl F1-F12}
	END;{KEYREC}

(* end of file "terminal.inc" *)
